@@ -18,13 +18,13 @@ models = list(map_model.keys())
 name_holder = {
     'LinearRegression' : 'Linear Regression',
     'Ridge' : "Ridge Regression",
-    'Lasso' : "Lasso Regression",
-    'DecisionTreeRegressor' : 'Decision Tree Regression',
-    'RandomForestRegressor' : 'Random Forest Regression',
-    'AdaBoostRegressor' : 'AdaBoost Regression',
-    'ExtraTreesRegressor' : 'Extra Trees Regression',
-    'BaggingRegressor' : 'Bagging Regression',
-    'GradientBoostingRegressor' : 'Gradient Boosting Regression',
+    'Lasso' : "Lasso",
+    'DecisionTreeRegressor' : 'Decision Tree Regressor',
+    'RandomForestRegressor' : 'Random Forest Regressor',
+    'AdaBoostRegressor' : 'AdaBoost Regressor',
+    'ExtraTreesRegressor' : 'ExtraTreesRegressor',
+    'BaggingRegressor' : 'Bagging Regressor',
+    'GradientBoostingRegressor' : 'Gradient Boosting Regressor',
     'LogisticRegression' : 'Logistic Regression',
     'RandomForestClassifier' : 'Random Forest Classifier',
     'AdaBoostClassifier' : 'AdaBoost Classifier',
@@ -40,8 +40,28 @@ name_holder = {
     'anova_regressor' : 'ANOVA',
     'anova_classifier' : 'ANOVA',
     'correlation' : 'Correlation Method',
-    'pca' : 'Principal Component Analysis',
-    'select_from_model' : 'Select from Model'
+    'pca' : 'Pricipal Component Analysis',
+    'select_from_model' : 'Select From Model'
+}
+
+column_holder={
+    'Meta Layer Model':'Meta Layer Model',
+    'Base Layer Models':'Base Layer Models',
+    'r2':'R2 Score',
+    'rmse':'RMSE',
+    'mae':'MAE',
+    'precision':'Precsion',
+    'precision_micro':'Precsion Micro',
+    'precision_macro':'Precison Macro',
+    'recall':'Recall',
+    'recall_micro':'Recall Micro',
+    'recall_macro':'Recall Macro',
+    'f1':'F1 Score',
+    'f1_micro':'F1 Score Micro',
+    'f1_macro':'F1 Score Macro',
+    'Estimator':'Estimator'
+    'Feature Engineering Method':'Feature Engineering Method',
+    'Hyperparameter Optimization Method':'Hyperparameter Optimization Method'
 }
 
 techniques_dict = {
@@ -216,6 +236,9 @@ def auto_trainer(dataset,label,task,feature_engineering_methods=default_feature_
     
     pd_stats = pd.DataFrame(stats)
     pd_stats.drop(pd_stats.columns[0], axis=1,inplace=True)
+
+    for change_column in range(len(column_names)):
+        column_names[change_column]=column_holder[column_names[change_column]]
     pd_stats.columns = column_names
 
     #Download excelsheet
